@@ -2,18 +2,15 @@
 #' @importFrom stats dbeta
 NULL
 
-#' plot distribution details as a density plus matching normal
+#' Plot an empirical density with the matching normal distribution
 #'
-#' assumes that xvar is a factor variable
-#' sort < 0 sorts the factor levels in decreasing order (most frequent level first)
-#' sort > 0 sorts the factor levels in increasing order (good when used in conjunction with coord_flip())
-#' sort = 0 leaves the factor levels in "natural order" -- usually alphabetical
-#' stem = FALSE will plot only the dots, without the stem to the y=0 line.
-#' limit_n = NULL plots all the levels, N an integer limits to the top N most populous levels
+#' Compares empirical data to a normal distribution with the same mean and standard deviation.
+#'
+#' Plots the empirical density, the theoretical matching normal, the mean value,
+#' and plus/minus one standard deviation from the mean.
 #' @param frm data frame to get values from
 #' @param xvar name of the independent (input or model) column in frame
 #' @param title title to place on plot
-#' @param ...  no unnamed argument, added to force named binding of later arguments.
 #' @examples
 #'
 #' set.seed(52523)
@@ -21,7 +18,12 @@ NULL
 #' PlotDistDensityNormal(d,'wt','example')
 #'
 #' @export
-PlotDistDensityNormal <- function(frm,xvar,title,...) {
+PlotDistDensityNormal <- function(frm, xvar, title) {
+  frm <- check_frame_args_list(# ...,
+                               frame = frm,
+                               name_var_list = list(xvar = xvar),
+                               title = title,
+                               funname = "WVPlots::PlotDistDensityNormal")
   x <- frm[[xvar]]
   dPlot <- data.frame(x=x)
   colnames(dPlot) <- xvar
@@ -47,19 +49,22 @@ PlotDistDensityNormal <- function(frm,xvar,title,...) {
 }
 
 
-#' plot distribution details as a histogram plus matching normal
+#' Plot distribution details as a histogram plus matching normal
+#'
+#' Compares empirical data to a normal distribution with the same mean and standard deviation.
+#'
+#' Plots the histograms of the empirical distribution and of the matching normal distribution.
+#' Also plots the mean and plus/minus one standard deviation.
+#'
+#' Bin width for the histogram is calculated automatically to yield approximately 50 bins across the
+#' range of the data, unless the \code{binWidth} argument is explicitly passed in. \code{binWidth} is reported
+#' in the subtitle of the plot.
 #'
-#' assumes that xvar is a factor variable
-#' sort < 0 sorts the factor levels in decreasing order (most frequent level first)
-#' sort > 0 sorts the factor levels in increasing order (good when used in conjunction with coord_flip())
-#' sort = 0 leaves the factor levels in "natural order" -- usually alphabetical
-#' stem = FALSE will plot only the dots, without the stem to the y=0 line.
-#' limit_n = NULL plots all the levels, N an integer limits to the top N most populous levels
 #' @param frm data frame to get values from
 #' @param xvar name of the independent (input or model) column in frame
 #' @param title title to place on plot
 #' @param ...  no unarmed argument, added to force named binding of later arguments.
-#' @param binWidth with of histogram bins
+#' @param binWidth width of histogram bins
 #' @examples
 #'
 #' set.seed(52523)
@@ -67,12 +72,19 @@ PlotDistDensityNormal <- function(frm,xvar,title,...) {
 #' PlotDistCountNormal(d,'wt','example')
 #'
 #' @export
-PlotDistCountNormal <- function(frm,xvar,title,...,binWidth=c()) {
+PlotDistCountNormal <- function(frm, xvar, title,
+                                ...,
+                                binWidth=c()) {
+  frm <- check_frame_args_list(...,
+    frame = frm,
+    name_var_list = list(xvar = xvar),
+    title = title,
+    funname = "WVPlots::PlotDistCountNormal")
   x <- frm[[xvar]]
   if(is.null(binWidth)) {
     range <- max(x)-min(x)
     if(range<=0) {
-      binWith <- 1
+      binWidth <- 1
     } else {
       binWidth <- 10^ceiling(log(range,10))/50
     }
@@ -104,6 +116,9 @@ PlotDistCountNormal <- function(frm,xvar,title,...,binWidth=c()) {
   # plotted area is going to be re-scale by both number of observations and binWidth
   dDist$count <- length(x)*binWidth*dnorm(dDist[[xvar]],mean=meanx,sd=sdx)
   # plot
+
+  subtitle = paste('binWidth =', format(binWidth))
+
   ggplot2::ggplot(data=dHist,
                   mapping=ggplot2::aes_string(x=xvar,y='count',ymax='count')) +
     ggplot2::geom_linerange(data=dTheory,ggplot2::aes(ymin=0),size=4,alpha=0.5,color='blue') +
@@ -113,22 +128,19 @@ PlotDistCountNormal <- function(frm,xvar,title,...,binWidth=c()) {
     ggplot2::geom_vline(xintercept=meanx,color='blue',linetype=2) +
     ggplot2::geom_vline(xintercept=meanx+sdx,color='blue',linetype=2) +
     ggplot2::geom_vline(xintercept=meanx-sdx,color='blue',linetype=2) +
-    ggplot2::ggtitle(paste(title,'\n','binWidth=',format(binWidth)))
+    ggplot2::ggtitle(title, subtitle=subtitle)
 }
 
-
-#' plot distribution details as a density plus matching beta
+#' Plot an empirical density with the matching beta distribution
+#'
+#' Compares empirical data to a beta distribution with the same mean and standard deviation.
+#'
+#' Plots the empirical density, the theoretical matching beta, the mean value,
+#' and plus/minus one standard deviation from the mean.
 #'
-#' assumes that xvar is a factor variable
-#' sort < 0 sorts the factor levels in decreasing order (most frequent level first)
-#' sort > 0 sorts the factor levels in increasing order (good when used in conjunction with coord_flip())
-#' sort = 0 leaves the factor levels in "natural order" -- usually alphabetical
-#' stem = FALSE will plot only the dots, without the stem to the y=0 line.
-#' limit_n = NULL plots all the levels, N an integer limits to the top N most populous levels
 #' @param frm data frame to get values from
 #' @param xvar name of the independent (input or model) column in frame
 #' @param title title to place on plot
-#' @param ...  no unnamed argument, added to force named binding of later arguments.
 #' @examples
 #'
 #' set.seed(52523)
@@ -136,7 +148,12 @@ PlotDistCountNormal <- function(frm,xvar,title,...,binWidth=c()) {
 #' PlotDistDensityBeta(d,'wt','example')
 #'
 #' @export
-PlotDistDensityBeta <- function(frm,xvar,title,...) {
+PlotDistDensityBeta <- function(frm, xvar, title) {
+  frm <- check_frame_args_list(#...,
+                               frame = frm,
+                               name_var_list = list(xvar = xvar),
+                               title = title,
+                               funname = "WVPlots::PlotDistDensityBeta")
   x <- frm[[xvar]]
   dPlot <- data.frame(x=x)
   colnames(dPlot) <- xvar
@@ -155,7 +172,9 @@ PlotDistDensityBeta <- function(frm,xvar,title,...) {
   ggplot2::ggplot() +
     ggplot2::geom_density(data=dPlot,
                           mapping=ggplot2::aes_string(x=xvar),
-                          adjust=0.5) +
+                          adjust=0.5,
+                          fill = "lightgray",
+                          color = NA) +
     ggplot2::geom_line(data=dDist,
                        mapping=ggplot2::aes_string(x=xvar,y='density'),
                        color='blue',linetype=2) +
@@ -165,19 +184,25 @@ PlotDistDensityBeta <- function(frm,xvar,title,...) {
     ggplot2::ggtitle(title)
 }
 
-
-#' plot distribution details as a density plus matching beta
+#' Plot distribution details as a histogram plus matching beta
+#'
+#' Compares empirical data to a beta distribution with the same mean and standard deviation.
+#'
+#' Plots the histogram of the empirical distribution and the density of the matching beta distribution.
+#' Also plots the mean and plus/minus one standard deviation.
+#'
+#' The number of bins for the histogram defaults to 30.
+#' The binwidth can also be passed in instead of the number of bins.
 #'
-#' assumes that xvar is a factor variable
-#' sort < 0 sorts the factor levels in decreasing order (most frequent level first)
-#' sort > 0 sorts the factor levels in increasing order (good when used in conjunction with coord_flip())
-#' sort = 0 leaves the factor levels in "natural order" -- usually alphabetical
-#' stem = FALSE will plot only the dots, without the stem to the y=0 line.
-#' limit_n = NULL plots all the levels, N an integer limits to the top N most populous levels
 #' @param frm data frame to get values from
 #' @param xvar name of the independent (input or model) column in frame
 #' @param title title to place on plot
-#' @param ...  no unnamed argument, added to force named binding of later arguments.
+#' @param ... force later arguments to bind by name
+#' @param binwidth passed to geom_histogram(). If passed in, overrides bins.
+#' @param bins passed to geom_histogram(). Default: 30
+#' @return ggplot2 plot
+#'
+#'
 #' @examples
 #'
 #' set.seed(52523)
@@ -185,7 +210,14 @@ PlotDistDensityBeta <- function(frm,xvar,title,...) {
 #' PlotDistHistBeta(d,'wt','example')
 #'
 #' @export
-PlotDistHistBeta <- function(frm,xvar,title,...) {
+PlotDistHistBeta <- function(frm, xvar, title,
+                             ...,
+                             binwidth = NULL, bins = 30) {
+  frm <- check_frame_args_list(...,
+    frame = frm,
+    name_var_list = list(xvar = xvar),
+    title = title,
+    funname = "WVPlots::PlotDistHistBeta")
   x <- frm[[xvar]]
   dPlot <- data.frame(x=x)
   colnames(dPlot) <- xvar
@@ -204,7 +236,8 @@ PlotDistHistBeta <- function(frm,xvar,title,...) {
   dDist$count <- length(x)*dDist$density/sum(dDist$densit)
   ggplot2::ggplot() +
     ggplot2::geom_histogram(data=dPlot,
-                          mapping=ggplot2::aes_string(x=xvar)) +
+                          mapping=ggplot2::aes_string(x=xvar),
+                          binwidth = binwidth, bins = bins) +
     ggplot2::geom_line(data=dDist,
                        mapping=ggplot2::aes_string(x=xvar,y='count'),
                        color='blue',linetype=2) +
